import { UserData, type z } from '@mongodb-js/compass-user-data';
import { RecentQuerySchema, FavoriteQuerySchema, type RecentQuery, type FavoriteQuery } from './query-storage-schema';
import type { FavoriteQueryStorage, RecentQueryStorage } from './query-storage';
export type QueryStorageOptions = {
    basepath?: string;
};
export interface QueryStorageBackend<TData> {
    loadAll(namespace?: string): Promise<TData[]>;
    updateAttributes(id: string, data: Partial<TData>): Promise<TData>;
    delete(id: string): Promise<boolean>;
    saveQuery(data: Omit<TData, '_id' | '_lastExecuted'>): Promise<void>;
}
export declare abstract class CompassQueryStorage<TSchema extends z.Schema, TData extends z.output<TSchema> = z.output<TSchema>> implements QueryStorageBackend<TData> {
    protected readonly folder: string;
    protected readonly options: QueryStorageOptions;
    protected readonly userData: UserData<TSchema>;
    constructor(schemaValidator: TSchema, folder: string, options: QueryStorageOptions);
    loadAll(namespace?: string): Promise<TData[]>;
    updateAttributes(id: string, data: Partial<TData>): Promise<TData>;
    delete(id: string): Promise<boolean>;
    abstract saveQuery(data: any): Promise<void>;
}
export declare class CompassRecentQueryStorage extends CompassQueryStorage<typeof RecentQuerySchema, RecentQuery> implements RecentQueryStorage {
    private readonly maxAllowedQueries;
    constructor(options?: QueryStorageOptions);
    saveQuery(data: Omit<z.input<typeof RecentQuerySchema>, '_id' | '_lastExecuted'>): Promise<void>;
}
export declare class CompassFavoriteQueryStorage extends CompassQueryStorage<typeof FavoriteQuerySchema, FavoriteQuery> implements FavoriteQueryStorage {
    constructor(options?: QueryStorageOptions);
    saveQuery(data: Omit<z.input<typeof FavoriteQuerySchema>, '_id' | '_lastExecuted' | '_dateModified' | '_dateSaved'>): Promise<void>;
}
//# sourceMappingURL=compass-query-storage.d.ts.map